LINEIN, LINEOUT - Input / Output


The S/REXX LINEIN() and LINEOUT() functions comply with the standard REXX
LINEIN() and LINEOUT() functions as described in "The REXX Programming
Language".

The following peculiarities must be noted:

The UNIX or WINDOWS file system does not know about lines, only about
characters. The lines delimiter is implied by the presence of the "0A"x
newline character on UNIX, and by the ^M character followed by the newline
character on WINDOWS.

At the first LINEIN() or LINEOUT() invocation, S/REXX scans the entire
file and memorizes the newline character positions, generating an
extremely fast line access on subsequent calls.

When using the LINEOUT() function to write in the middle of a file, for
example to write a string at line 10 of a 2000 line file, S/REXX does not
truncate the file at line 10. Instead, it checks the string length,
compares it to the original line 10 length, and moves the remainder of the
file either to the left or to the right, depending on whether the new line
is shorter (left) or longer (right) than the original line.

With large files, this process may take a while.


The filename parameter may include the ~ .. file meta characters.

When reading the standard input, LINEIN() sets the special RC REXX
variable to 0 in case of success, and to the 'EOF' uppercase string when
the standard input is no longer available. In that case, LINEIN() returns
an empty string. This allows the use of an S/REXX program as a standard
input filter.

Consider the following test program:

-------------------------------------------------------------------------
#! /home/xed/srexx
do forever
  val = linein()
  if rc = 'EOF' then exit
  say upper(val)
end
-------------------------------------------------------------------------

Typing (using an UNIX shell):

-------------------------------------------------------------------------
echo abc | test
-------------------------------------------------------------------------


would display:

-------------------------------------------------------------------------
ABC
-------------------------------------------------------------------------


See Also: FILECONV
